==> KidozSDK-0.1.4-sources.jar: com/kidoz/sdk/api/general/enums/ContentType.java <==
package com.kidoz.sdk.api.general.enums;


import java.util.HashMap;
import java.util.Map;

/**
 * Created by Eugine on 14/07/2015.
 *
 * Content types
 */
public enum ContentType {

    NONE,
    YOTUBE_VIDEO,
    GOOGLE_PLAY_APPLICATION,
    PROMOTED_PLAY_APPLICATION,
    WEB_GAME_URL,
    WEBSITE_URL,
    STREAMING_VIDEO,
    VIMEO_VIDEO
    ;

    private static final Map<ContentType, Integer> lookup = new HashMap<ContentType, Integer>();
    private static final Map<Integer, ContentType> reverseLookup = new HashMap<Integer, ContentType>();

    static
    {
        // Lookup
        lookup.put(NONE, -1);
        lookup.put(YOTUBE_VIDEO, 0);
        lookup.put(GOOGLE_PLAY_APPLICATION, 1);
        lookup.put(PROMOTED_PLAY_APPLICATION, 2);
        lookup.put(WEB_GAME_URL, 3);
        lookup.put(WEBSITE_URL, 4);
        lookup.put(STREAMING_VIDEO, 5);
        lookup.put(VIMEO_VIDEO, 6);

        // Reverse Lookup
        reverseLookup.put(-1, NONE);
        reverseLookup.put(0, YOTUBE_VIDEO);
        reverseLookup.put(1, GOOGLE_PLAY_APPLICATION);
        reverseLookup.put(2, PROMOTED_PLAY_APPLICATION);
        reverseLookup.put(3, WEB_GAME_URL);
        reverseLookup.put(4, WEBSITE_URL);
        reverseLookup.put(5, STREAMING_VIDEO);
        reverseLookup.put(6, VIMEO_VIDEO);

    }

    public static int getValueFromType(ContentType inVal)
    {
        return lookup.get(inVal);
    }

    public static ContentType getTypeByValue(int val)
    {
        return reverseLookup.get(val);
    }
}

==> KidozSDK-0.3.0-sources.jar: com/kidoz/sdk/api/general/enums/ContentType.java <==
package com.kidoz.sdk.api.general.enums;


import java.util.HashMap;
import java.util.Map;

/**
 * Created by Eugine on 14/07/2015.
 *
 * Content types
 */
public enum ContentType {

    NONE,
    YOTUBE_VIDEO,
    GOOGLE_PLAY_APPLICATION,
    PROMOTED_PLAY_APPLICATION,
    WEB_GAME_URL,
    WEBSITE_URL,
    STREAMING_VIDEO,
    VIMEO_VIDEO,
    EXTERNAL_BROWSER_URL;


    private static final Map<ContentType, Integer> lookup = new HashMap<ContentType, Integer>();
    private static final Map<Integer, ContentType> reverseLookup = new HashMap<Integer, ContentType>();

    static
    {
        // Lookup
        lookup.put(NONE, -1);
        lookup.put(YOTUBE_VIDEO, 0);
        lookup.put(GOOGLE_PLAY_APPLICATION, 1);
        lookup.put(PROMOTED_PLAY_APPLICATION, 2);
        lookup.put(WEB_GAME_URL, 3);
        lookup.put(WEBSITE_URL, 4);
        lookup.put(STREAMING_VIDEO, 5);
        lookup.put(VIMEO_VIDEO, 6);
        lookup.put(EXTERNAL_BROWSER_URL, 7);

        // Reverse Lookup
        reverseLookup.put(-1, NONE);
        reverseLookup.put(0, YOTUBE_VIDEO);
        reverseLookup.put(1, GOOGLE_PLAY_APPLICATION);
        reverseLookup.put(2, PROMOTED_PLAY_APPLICATION);
        reverseLookup.put(3, WEB_GAME_URL);
        reverseLookup.put(4, WEBSITE_URL);
        reverseLookup.put(5, STREAMING_VIDEO);
        reverseLookup.put(6, VIMEO_VIDEO);
        reverseLookup.put(7, EXTERNAL_BROWSER_URL);

    }

    public static int getValueFromType(ContentType inVal)
    {
        return lookup.get(inVal);
    }

    public static ContentType getTypeByValue(int val)
    {
        return reverseLookup.get(val);
    }
}
